==> qtjambi-xml-5.15.8-sources.jar: io/qt/xml/QXmlDTDHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report DTD content of XML data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html">QXmlDTDHandler</a></p>
 */
@Deprecated
public interface QXmlDTDHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlDTDHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlDTDHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlDTDHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean notationDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId){
                return notationDecl_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, publicId, systemId);
            }
            private native static boolean notationDecl_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean unparsedEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName){
                return unparsedEntityDecl_native_cref_QString_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, publicId, systemId, notationName);
            }
            private native static boolean unparsedEntityDecl_native_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlDTDHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#errorString">QXmlDTDHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#notationDecl">QXmlDTDHandler::notationDecl(QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean notationDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        private native static boolean notationDecl_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#unparsedEntityDecl">QXmlDTDHandler::unparsedEntityDecl(QString,QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean unparsedEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName);
        
        private native static boolean unparsedEntityDecl_native_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#errorString">QXmlDTDHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#notationDecl">QXmlDTDHandler::notationDecl(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean notationDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#unparsedEntityDecl">QXmlDTDHandler::unparsedEntityDecl(QString,QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean unparsedEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName);
    
}

==> qtjambi-xml-5.15.10-sources.jar: io/qt/xml/QXmlDTDHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report DTD content of XML data</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html">QXmlDTDHandler</a></p>
 */
@Deprecated
public interface QXmlDTDHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlDTDHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlDTDHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlDTDHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean notationDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId){
                return notationDecl_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, publicId, systemId);
            }
            private native static boolean notationDecl_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean unparsedEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName){
                return unparsedEntityDecl_native_cref_QString_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, publicId, systemId, notationName);
            }
            private native static boolean unparsedEntityDecl_native_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlDTDHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#errorString">QXmlDTDHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#notationDecl">QXmlDTDHandler::notationDecl(QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean notationDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        private native static boolean notationDecl_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#unparsedEntityDecl">QXmlDTDHandler::unparsedEntityDecl(QString,QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean unparsedEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName);
        
        private native static boolean unparsedEntityDecl_native_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#errorString">QXmlDTDHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#notationDecl">QXmlDTDHandler::notationDecl(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean notationDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldtdhandler.html#unparsedEntityDecl">QXmlDTDHandler::unparsedEntityDecl(QString,QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean unparsedEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId, java.lang.String notationName);
    
}
